@@ -50,6 +50,8 @@ def getFilePath(url):
 def cachedContent(url, headers={}, mode='', encoding='utf-8', sleep=0, ttl=float('inf')):
     cache = getFilePath(url)
     try:
+        while os.path.getmtime(cache) > time.time() - 5:
+            time.sleep(5) # for video file in saving
         if (ttl == float('inf') or 
             os.path.getmtime(cache) > time.time() - ttl):
             with open(cache, 'r' + mode) as f:
